@@ -1,9 +1,10 @@
 import pathlib
 import click
 
-from sigma.collection import SigmaCollection
 from sigma.exceptions import SigmaError
 
+from sigma.cli.rules import load_rules
+
 @click.command()
 @click.option(
     "--file-pattern", "-P",
@@ -19,13 +20,16 @@ from sigma.exceptions import SigmaError
 def check(input, file_pattern):
     """Check Sigma rules for validity and best practices (not yet implemented)."""
     try:
-        rule_collection = SigmaCollection.load_ruleset(
-            input,
-            recursion_pattern="**/" + file_pattern,
-            collect_errors=True,
-            )
+        rule_collection = load_rules(input, file_pattern)
+        error_count = 0
         for rule in rule_collection.rules:
             for error in rule.errors:
                 click.echo(error)
+                error_count += 1
+        if error_count > 0:
+            click.echo(f"Found {error_count} errors!")
+            click.get_current_context().exit(1)
+        else:
+            click.echo("No errors found!")
     except SigmaError as e:
         click.echo("Check error: " + str(e), err=True)
\ No newline at end of file
